==> qore-1.18.0.tar.bz2: qore-1.18.0/docs/modules/ConnectionProvider/html/class_connection_provider_1_1_abstract_connection.js <==
var class_connection_provider_1_1_abstract_connection =
[
    [ "constructor", "class_connection_provider_1_1_abstract_connection.html#aab3b7ec5c81d1ed61242d2803c5af36d", null ],
    [ "constructor", "class_connection_provider_1_1_abstract_connection.html#ab8c1d6d2e0bd71ff763fdddd7452bd6f", null ],
    [ "constructorInit", "class_connection_provider_1_1_abstract_connection.html#a03bb7c6556756529297a54819d1a80e5", null ],
    [ "get", "class_connection_provider_1_1_abstract_connection.html#a1d1e6c58a9d932884cab046315015c2c", null ],
    [ "getConfigHash", "class_connection_provider_1_1_abstract_connection.html#aa0366f924783e0daab4ea4db9b6ee05e", null ],
    [ "getConnectionSchemeInfo", "class_connection_provider_1_1_abstract_connection.html#a87dd7da949114c4a37ee6299eebeaf01", null ],
    [ "getConnectionSchemeInfoImpl", "class_connection_provider_1_1_abstract_connection.html#a8f5adb01d95a386b0c19bdc3c05aa95c", null ],
    [ "getDataProvider", "class_connection_provider_1_1_abstract_connection.html#a6a2ca0999875315a6b071c4c98c72ad9", null ],
    [ "getDefaultOptions", "class_connection_provider_1_1_abstract_connection.html#ab892ee296676233f64e17170522462f5", null ],
    [ "getDescription", "class_connection_provider_1_1_abstract_connection.html#a846e516ea125ddd4dc53e557dc5427d2", null ],
    [ "getExtendedInfo", "class_connection_provider_1_1_abstract_connection.html#a472cf3232377260515399d7ae1fdc328", null ],
    [ "getImpl", "class_connection_provider_1_1_abstract_connection.html#aab2383140a94c4e87f14a329fbad2c10", null ],
    [ "getInfo", "class_connection_provider_1_1_abstract_connection.html#a098bdbf1d3bd604d85c0e75479f890e5", null ],
    [ "getInfo", "class_connection_provider_1_1_abstract_connection.html#a0b0ae8c20766e83c9405dfa61ba69c85", null ],
    [ "getName", "class_connection_provider_1_1_abstract_connection.html#a06a1fdea1f3f8d0ec6d91003060c4c88", null ],
    [ "getOptions", "class_connection_provider_1_1_abstract_connection.html#aa9bdf384efcc764ad114611bfafdc626", null ],
    [ "getPollImpl", "class_connection_provider_1_1_abstract_connection.html#a191065efc2c1ee4757c8bec97f08c968", null ],
    [ "getRealOptions", "class_connection_provider_1_1_abstract_connection.html#af2fd8f463111b910605fc953b05bb555", null ],
    [ "getRuntimeOptions", "class_connection_provider_1_1_abstract_connection.html#a30c2adeea8c2d9d624e7d36e402086a2", null ],
    [ "getSafeUrl", "class_connection_provider_1_1_abstract_connection.html#ab0757963d945620257383444de5c6713", null ],
    [ "getSafeUrl", "class_connection_provider_1_1_abstract_connection.html#a661753ef54d2f5e4650be5f96114fdba", null ],
    [ "getTag", "class_connection_provider_1_1_abstract_connection.html#abb1512d2bb930400633549d1392a91f2", null ],
    [ "getTagEx", "class_connection_provider_1_1_abstract_connection.html#a27b8282bb476eaa937ce98002350e56f", null ],
    [ "getTags", "class_connection_provider_1_1_abstract_connection.html#aaacf943d9e4189fa7ebc90a2ada165c3", null ],
    [ "getType", "class_connection_provider_1_1_abstract_connection.html#ad6360ab13a9b6ee77a42494a78f40f07", null ],
    [ "getUrl", "class_connection_provider_1_1_abstract_connection.html#ab46ffb96fde5f44526a27dffdf7833f5", null ],
    [ "handlePingFailed", "class_connection_provider_1_1_abstract_connection.html#aab9f3c11eb9d42d4c8eab00ac6aa440e", null ],
    [ "handlePingFailed", "class_connection_provider_1_1_abstract_connection.html#ade04bc7a2cfd57e65a8d528567f91ae3", null ],
    [ "handlePingSuccess", "class_connection_provider_1_1_abstract_connection.html#afc178eef5793522a040c38a59cd49757", null ],
    [ "hasDataProvider", "class_connection_provider_1_1_abstract_connection.html#a0c5757475a8d7b3b7bde185f355f68dd", null ],
    [ "parseTextOptions", "class_connection_provider_1_1_abstract_connection.html#ac61a1274cdf728aa75cbedc9637fa26f", null ],
    [ "parseUrl", "class_connection_provider_1_1_abstract_connection.html#a9f9118a459bb923af2f35124bb1e248e", null ],
    [ "ping", "class_connection_provider_1_1_abstract_connection.html#ae3dceb6db1076a8e0af1e0dce5e4b127", null ],
    [ "pingImpl", "class_connection_provider_1_1_abstract_connection.html#a0742687954adc1d353c763ccb4db30f4", null ],
    [ "pingIntern", "class_connection_provider_1_1_abstract_connection.html#a8f867a9f5c4547f0525455b771ee978c", null ],
    [ "setChildCapabilities", "class_connection_provider_1_1_abstract_connection.html#a5f21738a1589d6c26da997a2e64e1fc8", null ],
    [ "startPollConnect", "class_connection_provider_1_1_abstract_connection.html#a5fe8e5abcca10385523ffe6d130fa3d1", null ],
    [ "supportsPollingApi", "class_connection_provider_1_1_abstract_connection.html#a9089c2203def6df8aad7a47f09b7a6ae", null ],
    [ "validateOptions", "class_connection_provider_1_1_abstract_connection.html#a83b06665e58255ab84ebfee255c673d5", null ],
    [ "children_can_support_apis", "class_connection_provider_1_1_abstract_connection.html#acb347c6f7e26ba93fa99e92880aaa905", null ],
    [ "children_can_support_messages", "class_connection_provider_1_1_abstract_connection.html#a3402c34f816abaaa2c89bb49aa3d2cb5", null ],
    [ "children_can_support_observers", "class_connection_provider_1_1_abstract_connection.html#ad00a02ab487f53a046d148ca0de58715", null ],
    [ "children_can_support_records", "class_connection_provider_1_1_abstract_connection.html#ad631d6e27d3a86d3407c94dd014afd1b", null ],
    [ "children_can_support_transactions", "class_connection_provider_1_1_abstract_connection.html#a0e749dc8ac03ffd6f8faf498d708403f", null ],
    [ "debug_data", "class_connection_provider_1_1_abstract_connection.html#a9604eec963b454961be927a46cbc0e7b", null ],
    [ "desc", "class_connection_provider_1_1_abstract_connection.html#a00eae77c6ed7ea309cce2d2d4b1d00dd", null ],
    [ "enabled", "class_connection_provider_1_1_abstract_connection.html#a662ad670d8b5a07a6342c04600f769a1", null ],
    [ "internal_info", "class_connection_provider_1_1_abstract_connection.html#a2a1103d6bd5af91a314c568257870ad3", null ],
    [ "last_check", "class_connection_provider_1_1_abstract_connection.html#a7a2c2893b72d01ee7538a36fbe725fc0", null ],
    [ "locked", "class_connection_provider_1_1_abstract_connection.html#a0433cb38a4138ce46220c469bd39b167", null ],
    [ "loopback", "class_connection_provider_1_1_abstract_connection.html#ace9d96ecd9edf5c7ec1b33afda402ff4", null ],
    [ "monitor", "class_connection_provider_1_1_abstract_connection.html#a4c7196e5ef17c086a6e71e95a2d0bfcf", null ],
    [ "name", "class_connection_provider_1_1_abstract_connection.html#a9dc813e9c1fcfc50234731eca3ac9ac6", null ],
    [ "opts", "class_connection_provider_1_1_abstract_connection.html#a133a28b83a8baa994130bfa5e47fc235", null ],
    [ "orig_opts", "class_connection_provider_1_1_abstract_connection.html#a2fb6cfafb19d7f777cd9cbb58ab439ec", null ],
    [ "safe_url", "class_connection_provider_1_1_abstract_connection.html#a55f96b36c1950d253345ef08622b302c", null ],
    [ "status", "class_connection_provider_1_1_abstract_connection.html#ac5adefaca64e104bc6c8f79495b9673c", null ],
    [ "tags", "class_connection_provider_1_1_abstract_connection.html#a635075e7428fba668f103b2c6cda5d86", null ],
    [ "transient_info", "class_connection_provider_1_1_abstract_connection.html#aa8acdf38d7ff5ebc49723466ced203e5", null ],
    [ "up", "class_connection_provider_1_1_abstract_connection.html#a823146a8cf2142a35fcdd210ed6836f7", null ],
    [ "updated", "class_connection_provider_1_1_abstract_connection.html#ac95aadbc16f82a118b0828f27f0590b5", null ],
    [ "url", "class_connection_provider_1_1_abstract_connection.html#a334f3d3871e9ed99b1ad683914cd63de", null ],
    [ "urlh", "class_connection_provider_1_1_abstract_connection.html#ae206ae81bc6de1cc405f48ed31a2baf4", null ]
];

==> qore-1.19.1.tar.bz2: qore-1.19.1/docs/modules/ConnectionProvider/html/class_connection_provider_1_1_abstract_connection.js <==
var class_connection_provider_1_1_abstract_connection =
[
    [ "constructor", "class_connection_provider_1_1_abstract_connection.html#aab3b7ec5c81d1ed61242d2803c5af36d", null ],
    [ "constructor", "class_connection_provider_1_1_abstract_connection.html#a3491313510844f80ff0c6c7352e63f8f", null ],
    [ "constructorInit", "class_connection_provider_1_1_abstract_connection.html#a9a421f15808ed06b37a05c3bb45935cc", null ],
    [ "get", "class_connection_provider_1_1_abstract_connection.html#a1d1e6c58a9d932884cab046315015c2c", null ],
    [ "getConfigHash", "class_connection_provider_1_1_abstract_connection.html#aa0366f924783e0daab4ea4db9b6ee05e", null ],
    [ "getConnectionSchemeInfo", "class_connection_provider_1_1_abstract_connection.html#a87dd7da949114c4a37ee6299eebeaf01", null ],
    [ "getConnectionSchemeInfoImpl", "class_connection_provider_1_1_abstract_connection.html#a8f5adb01d95a386b0c19bdc3c05aa95c", null ],
    [ "getDataProvider", "class_connection_provider_1_1_abstract_connection.html#a6a2ca0999875315a6b071c4c98c72ad9", null ],
    [ "getDefaultOptions", "class_connection_provider_1_1_abstract_connection.html#ab892ee296676233f64e17170522462f5", null ],
    [ "getDescription", "class_connection_provider_1_1_abstract_connection.html#a846e516ea125ddd4dc53e557dc5427d2", null ],
    [ "getExtendedInfo", "class_connection_provider_1_1_abstract_connection.html#a472cf3232377260515399d7ae1fdc328", null ],
    [ "getFeatures", "class_connection_provider_1_1_abstract_connection.html#af70cd786423e6f8e23853d3b73c9fb0c", null ],
    [ "getFeaturesImpl", "class_connection_provider_1_1_abstract_connection.html#a3f25719e877ecfa2a32ac049f14c38a6", null ],
    [ "getImpl", "class_connection_provider_1_1_abstract_connection.html#aab2383140a94c4e87f14a329fbad2c10", null ],
    [ "getInfo", "class_connection_provider_1_1_abstract_connection.html#a098bdbf1d3bd604d85c0e75479f890e5", null ],
    [ "getInfo", "class_connection_provider_1_1_abstract_connection.html#a0b0ae8c20766e83c9405dfa61ba69c85", null ],
    [ "getName", "class_connection_provider_1_1_abstract_connection.html#a06a1fdea1f3f8d0ec6d91003060c4c88", null ],
    [ "getOptions", "class_connection_provider_1_1_abstract_connection.html#aa9bdf384efcc764ad114611bfafdc626", null ],
    [ "getPollImpl", "class_connection_provider_1_1_abstract_connection.html#a191065efc2c1ee4757c8bec97f08c968", null ],
    [ "getRealOptions", "class_connection_provider_1_1_abstract_connection.html#af2fd8f463111b910605fc953b05bb555", null ],
    [ "getRuntimeOptions", "class_connection_provider_1_1_abstract_connection.html#a30c2adeea8c2d9d624e7d36e402086a2", null ],
    [ "getSafeUrl", "class_connection_provider_1_1_abstract_connection.html#ab0757963d945620257383444de5c6713", null ],
    [ "getSafeUrl", "class_connection_provider_1_1_abstract_connection.html#a661753ef54d2f5e4650be5f96114fdba", null ],
    [ "getTag", "class_connection_provider_1_1_abstract_connection.html#abb1512d2bb930400633549d1392a91f2", null ],
    [ "getTagEx", "class_connection_provider_1_1_abstract_connection.html#a27b8282bb476eaa937ce98002350e56f", null ],
    [ "getTags", "class_connection_provider_1_1_abstract_connection.html#aaacf943d9e4189fa7ebc90a2ada165c3", null ],
    [ "getType", "class_connection_provider_1_1_abstract_connection.html#ad6360ab13a9b6ee77a42494a78f40f07", null ],
    [ "getUrl", "class_connection_provider_1_1_abstract_connection.html#ab46ffb96fde5f44526a27dffdf7833f5", null ],
    [ "handlePingFailed", "class_connection_provider_1_1_abstract_connection.html#aab9f3c11eb9d42d4c8eab00ac6aa440e", null ],
    [ "handlePingFailed", "class_connection_provider_1_1_abstract_connection.html#ade04bc7a2cfd57e65a8d528567f91ae3", null ],
    [ "handlePingSuccess", "class_connection_provider_1_1_abstract_connection.html#afc178eef5793522a040c38a59cd49757", null ],
    [ "hasDataProvider", "class_connection_provider_1_1_abstract_connection.html#a0c5757475a8d7b3b7bde185f355f68dd", null ],
    [ "parseTextOptions", "class_connection_provider_1_1_abstract_connection.html#ac61a1274cdf728aa75cbedc9637fa26f", null ],
    [ "parseUrl", "class_connection_provider_1_1_abstract_connection.html#a9f9118a459bb923af2f35124bb1e248e", null ],
    [ "ping", "class_connection_provider_1_1_abstract_connection.html#ae3dceb6db1076a8e0af1e0dce5e4b127", null ],
    [ "pingImpl", "class_connection_provider_1_1_abstract_connection.html#a0742687954adc1d353c763ccb4db30f4", null ],
    [ "pingIntern", "class_connection_provider_1_1_abstract_connection.html#a8f867a9f5c4547f0525455b771ee978c", null ],
    [ "setChildCapabilities", "class_connection_provider_1_1_abstract_connection.html#a5f21738a1589d6c26da997a2e64e1fc8", null ],
    [ "startPollConnect", "class_connection_provider_1_1_abstract_connection.html#a5fe8e5abcca10385523ffe6d130fa3d1", null ],
    [ "supportsPollingApi", "class_connection_provider_1_1_abstract_connection.html#a9089c2203def6df8aad7a47f09b7a6ae", null ],
    [ "validateOptions", "class_connection_provider_1_1_abstract_connection.html#a83b06665e58255ab84ebfee255c673d5", null ],
    [ "CF_LOGGER", "class_connection_provider_1_1_abstract_connection.html#a22a593b59fadee5f8af1d8297cfa6d94", null ],
    [ "CF_UPDATE_OPTIONS", "class_connection_provider_1_1_abstract_connection.html#a8e95dd62775329273d09271586e3126f", null ],
    [ "children_can_support_apis", "class_connection_provider_1_1_abstract_connection.html#acb347c6f7e26ba93fa99e92880aaa905", null ],
    [ "children_can_support_messages", "class_connection_provider_1_1_abstract_connection.html#a3402c34f816abaaa2c89bb49aa3d2cb5", null ],
    [ "children_can_support_observers", "class_connection_provider_1_1_abstract_connection.html#ad00a02ab487f53a046d148ca0de58715", null ],
    [ "children_can_support_records", "class_connection_provider_1_1_abstract_connection.html#ad631d6e27d3a86d3407c94dd014afd1b", null ],
    [ "children_can_support_transactions", "class_connection_provider_1_1_abstract_connection.html#a0e749dc8ac03ffd6f8faf498d708403f", null ],
    [ "debug_data", "class_connection_provider_1_1_abstract_connection.html#a9604eec963b454961be927a46cbc0e7b", null ],
    [ "desc", "class_connection_provider_1_1_abstract_connection.html#a00eae77c6ed7ea309cce2d2d4b1d00dd", null ],
    [ "enabled", "class_connection_provider_1_1_abstract_connection.html#a662ad670d8b5a07a6342c04600f769a1", null ],
    [ "internal_info", "class_connection_provider_1_1_abstract_connection.html#a2a1103d6bd5af91a314c568257870ad3", null ],
    [ "last_check", "class_connection_provider_1_1_abstract_connection.html#a7a2c2893b72d01ee7538a36fbe725fc0", null ],
    [ "locked", "class_connection_provider_1_1_abstract_connection.html#a0433cb38a4138ce46220c469bd39b167", null ],
    [ "loopback", "class_connection_provider_1_1_abstract_connection.html#ace9d96ecd9edf5c7ec1b33afda402ff4", null ],
    [ "monitor", "class_connection_provider_1_1_abstract_connection.html#a4c7196e5ef17c086a6e71e95a2d0bfcf", null ],
    [ "name", "class_connection_provider_1_1_abstract_connection.html#a9dc813e9c1fcfc50234731eca3ac9ac6", null ],
    [ "opts", "class_connection_provider_1_1_abstract_connection.html#a133a28b83a8baa994130bfa5e47fc235", null ],
    [ "orig_opts", "class_connection_provider_1_1_abstract_connection.html#a2fb6cfafb19d7f777cd9cbb58ab439ec", null ],
    [ "safe_url", "class_connection_provider_1_1_abstract_connection.html#a55f96b36c1950d253345ef08622b302c", null ],
    [ "status", "class_connection_provider_1_1_abstract_connection.html#ac5adefaca64e104bc6c8f79495b9673c", null ],
    [ "tags", "class_connection_provider_1_1_abstract_connection.html#a635075e7428fba668f103b2c6cda5d86", null ],
    [ "transient_info", "class_connection_provider_1_1_abstract_connection.html#aa8acdf38d7ff5ebc49723466ced203e5", null ],
    [ "up", "class_connection_provider_1_1_abstract_connection.html#a823146a8cf2142a35fcdd210ed6836f7", null ],
    [ "updated", "class_connection_provider_1_1_abstract_connection.html#ac95aadbc16f82a118b0828f27f0590b5", null ],
    [ "url", "class_connection_provider_1_1_abstract_connection.html#a334f3d3871e9ed99b1ad683914cd63de", null ],
    [ "urlh", "class_connection_provider_1_1_abstract_connection.html#ae206ae81bc6de1cc405f48ed31a2baf4", null ]
];
